NMCA - Slip Opinions

New Mexico Court of Appeals — Current Slip Opinions
| The slip opinion is the first version of an opinion released by the Chief Clerk of the Supreme Court. Once an opinion is selected for publication by the Court, it is assigned a vendor-neutral citation by the Chief Clerk for compliance with Rule 23-112 NMRA. The New Mexico Compilation Commission provides editorial services such as proofreading, applying court-approved corrections and topic indices. Once authenticated and formally published, the slip opinion is removed from the Slip Opinion page. Caution: The slip opinion may contain computer-generated errors or other deviations from the formal authenticated opinion. In case of discrepancies between a slip opinion and the authenticated formal opinion published under "Current Year Opinions" on this website, the authenticated opinion controls.
| Sorting options — The opinions may be sorted by "Filing Date", "Short Title", or "Docket No."
| Click on the column name/header — the opinions will sort in descending/ascending order.
| Note that the Short Title column contains the full text of the slip opinion in PDF format.
Filing Date | Short Title | Docket No.
--- | --- | ---
03/29/2012 | State v. Montoya | 30,470
07/18/2012 | Figueroa v. THI of NM at Casa Arena Blanca, LLC | 30,477
08/15/2012 | Sproul v. Rob & Charlies, Inc. | 31,167
01/16/2013 | State v. Garcia | 30,852
02/18/2013 | State v. Nieto | 30,806
03/06/2013 | State v. Parrish | 31,701
03/11/2013 | Cordova v. Cline | 30,546
03/13/2013 | Kimbrell v. Kimbrell | 30,447; 31,491
03/19/2013 | State v. Smith | 31,265
03/25/2013 | State v. Baca | 31,442
03/26/2013 | State ex rel. Children, Youth & Families Dep't v. Raquel M. | 31,869
04/01/2013 | State v. Steven B. | 31,322
04/02/2013 | Beggs v. City of Portales | 31,475
04/09/2013 | State, ex rel., Children, Youth, and Families Department v. Marsalee P. | 31,784
04/17/2013 | AFSCME Council 18 v. City of Albuquerque | 31,631
04/23/2013 | Narvaez v. NM Dept. of Workforce Solutions | 32,149; 32,256
04/24/2013 | N.M. Board of Licensure for Prof. Engineers v. Turner | 31,041
04/25/2013 | Faber v. King | 31,446
04/30/2013 | Beggs v. City of Portales | 31,475
05/01/2013 | Los Vigiles Land Grant v. Rebar Haygood Ranch, LLC | 31,325
05/03/2013 | State v. Orr | 31,626
05/09/2013 | State v. Bradford | 31,734
05/20/2013 | Slusser v. Vantage Builders, Inc. | 31,087
05/20/2013 | Ruiz v. Los Lunas Public Schools | 31,454
05/20/2013 | Laughlin v. Convenient Management Services, Inc. | 32,074
05/23/2013 | State v. Light | 30,741
05/23/2013 | Bernier v. Bernier | 31,607
05/29/2013 | State v. Redd | 31,558
06/03/2013 | Hinkle v. State Farm Fire & Casualty Co. | 31,707
06/03/2013 | Swift v. Bullington | 32,176; 32,180